@@ -1,29 +1,31 @@
 """Models used by django-historylinks."""
-
 from django.contrib.contenttypes.models import ContentType
-from django.contrib.contenttypes.generic import GenericForeignKey
+from django.contrib.contenttypes.fields import GenericForeignKey
 from django.db import models
 
 
 class HistoryLink(models.Model):
-    
+
     """A link to a moved / deleted model."""
-    
+
     permalink_name = models.CharField(
-        max_length = 255,
+        max_length=255,
     )
-    
+
     permalink = models.CharField(
-        max_length = 255,
-        unique = True,
+        max_length=255,
+        unique=True,
     )
-    
-    content_type = models.ForeignKey(ContentType)
-    
+
+    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
+
     object_id = models.TextField()
-    
+
     object = GenericForeignKey()
-    
-    def __unicode__(self):
+
+    def __str__(self):
         """Returns a unicode representation."""
-        return self.permalink
\ No newline at end of file
+        return self.permalink
+
+    class Meta:
+        app_label = "historylinks"
